MixedText

Struct MixedText 

pub struct MixedText { /* private fields */ }
MixedText is a component that renders a text string containing a mix of styles.

If you want to render a text string with a single style, use the Text component instead.

Example

element! {
    View(
        border_style: BorderStyle::Round,
        border_color: Color::Blue,
        width: 30,
    ) {
        MixedText(align: TextAlign::Center, contents: vec![
            MixedTextContent::new("Hello, world!").color(Color::Red).weight(Weight::Bold),
            MixedTextContent::new(" Lorem ipsum odor amet, consectetuer adipiscing elit.").color(Color::Green),
        ])
    }
}