pub struct MixedText { /* private fields */ }Expand description
MixedText is a component that renders a text string containing a mix of styles.
If you want to render a text string with a single style, use the Text component instead.
Example
element! {
View(
border_style: BorderStyle::Round,
border_color: Color::Blue,
width: 30,
) {
MixedText(align: TextAlign::Center, contents: vec![
MixedTextContent::new("Hello, world!").color(Color::Red).weight(Weight::Bold),
MixedTextContent::new(" Lorem ipsum odor amet, consectetuer adipiscing elit.").color(Color::Green),
])
}
}Trait Implementations
Sourceimpl Component for MixedText
impl Component for MixedText
Sourcetype Props<'a> = MixedTextProps
type Props<'a> = MixedTextProps
The type of properties that the component accepts.
Sourcefn new(_props: &Self::Props<'_>) -> Self
fn new(_props: &Self::Props<'_>) -> Self
Creates a new instance of the component from a set of properties.
Sourcefn update(
&mut self,
props: &mut Self::Props<'_>,
_hooks: Hooks<'_, '_>,
updater: &mut ComponentUpdater<'_, '_, '_>,
)
fn update( &mut self, props: &mut Self::Props<'_>, _hooks: Hooks<'_, '_>, updater: &mut ComponentUpdater<'_, '_, '_>, )
Invoked whenever the properties of the component or layout may have changed.
Sourcefn draw(&mut self, drawer: &mut ComponentDrawer<'_>)
fn draw(&mut self, drawer: &mut ComponentDrawer<'_>)
Invoked to draw the component.